const footer = require('./htmlFooter.js')

const tagListItem = (tag, doLink) => {
  let li = `    <li class="tag">`
  if (doLink) {
    li += `      <a class="link" href="tags/${tag}/">${tag}</a>`
  }
  else {
    li += tag
  }
  li += `</li>`
  return li
}
const tagsListItems = (tags, doLink=true) => tags.map(tag => tagListItem(tag, doLink)).join('\n')

const entryListItem = ({relativeUrl, title, date, tags}) => `    <li class="entry">
      <a class="link" title="${title}" href="${relativeUrl}">
        <span class="link-text">${title}</span>
        <div class="metadata">
          <div class="date">${date}</div><ul class="tags">
            ${tagsListItems(tags, false)}
          </ul>
        </div>
      </a>
    </li>`
const entriesListItems = (links) => links.map(entryListItem).join('\n')

module.exports = (links, tags) => 
`
<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <title>My Journal</title>
  <link href="styles.css" rel="stylesheet">
  <link rel="alternate" type="application/atom+xml" title="Feed for My Journal" href="feed.xml">
  <meta name="viewport" content="width=device-width,initial-scale=1">
  <meta name="generator" content="CMS ETL BBQ; https://tildegit.org/mycrobe/cmsetlbbq/issues/19" />
</head>
<body>
  <h1 class="title">My Journal</h1>
  <section class="blurb">
    <p>Excerpts from my Day One journal. These were never intended for public consumption so might be crap (but are clean, safe, etc). This is mostly an experiment in publishing something with my own tools.</p>
  </section>
  <div class="index-content">
  <section class="entries-section">
  <h2>Entries</h2>
  <ul class="entries">
${entriesListItems(links)}
  </ul>
  </section>
  <section class="tags-section">
  <h2>Tags</h2>
  <ul class="tags">
${tagsListItems(tags)}
  </ul>
  </section>
  </div>
${footer()}
</body>
`
